(function ($) {
    $(function () {
        $('.et-color').wpColorPicker();
    });

    $(".et-delete-img").on("click", function (e) {
        e.preventDefault();
        var image = $(this).data("input");

        $("#edtr_input_" + image).val(' ');
        $("#img_" + image).attr("src", 'data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==');
    });


    $(".et-preview").on("click", function () {
        var draftSettings = {
            partnerId: $("#edtr_input_edtr_general_partner_id").val(),

            colors: {
                primary: $("#edtr_input_edtr_primary_color").val(),
                primaryLight: $("#edtr_input_edtr_primary_light_color").val(),
                primaryActive: "",
                icon: $("#edtr_input_edtr_icon_color").val(),
            },

            icons: {
                headerIconUrl: $("#img_edtr_header_img").attr("src"),
                widgetIconUrl: $("#img_edtr_widget_icon").attr("src"),
                botIconUrl: $("#img_edtr_bot_icon").attr("src"),
            },

            preview: {
                imgUrl: $("#img_edtr_preview_img").attr("src"),
                title: $("#edtr_input_edtr_preview_title").val(),
                deeplink: $("#edtr_input_edtr_preview_deeplink").val()
            }
        };

        window.__ET_initTheme(draftSettings);
    });


    // MEDIA UPLOAD
    var mediaUploader;

    $("input.et-img-btn").on("click", function (e) {
        e.preventDefault();

        var cropControl = {
            id: "control-id",
            title: $(this).data('title'),
            params: {
                width: $(this).data('width'),  // set the desired width of the destination image here
                height: $(this).data('height'), // set the desired height of the destination image here
            }
        };

        var inputSlug = $(this).data('input');

        cropControl.mustBeCropped = function (dstW, dstH, imgW, imgH) {
            if (dstW === imgW && dstH === imgH) {
                return false;
            }

            return true;
        };

        window.edtr_requiredWidth = $(this).data('width'),
        window.edtr_requiredHeight = $(this).data('height');

        mediaUploader = wp.media({
            button: {
                text: 'Select & Crop',
                close: false
            },
            states: [


                new wp.media.controller.Library({
                    title: $(this).data('title'),
                    library: wp.media.query({ type: "image" }),
                    multiple: false,
                    displaySettings: false,
                    displayUserSettings: false,
                    aspectRatio: $(this).data('width') + ":" + $(this).data('height'),
                    suggestedWidth: Math.abs($(this).data('width')),
                    suggestedHeight: Math.abs($(this).data('height'))
                }),
                new wp.media.controller.CustomizeImageCropper({
                    imgSelectOptions: edtr_calculate_image_crop,
                    control: cropControl
                })
            ]
        });

        mediaUploader.on('cropped', function (croppedImage) {
            var url = croppedImage.url,
                attachmentId = croppedImage.attachment_id,
                w = croppedImage.width,
                h = croppedImage.height;

            edtr_setImageFromURL(url, attachmentId, w, h, inputSlug);
        });

        mediaUploader.on('skippedcrop', function (selection) {
            var url = selection.get('url'),
                w = selection.get('width'),
                h = selection.get('height');

            edtr_setImageFromURL(url, selection.id, w, h, inputSlug);
        });

        mediaUploader.on("select", function () {

            var attachment = mediaUploader.state().get('selection').first().toJSON();

            if (cropControl.params.width === attachment.width
                && cropControl.params.height === attachment.height) {
                edtr_setImageFromAttachment(attachment, inputSlug);
                mediaUploader.close().detach();
            } else {
                mediaUploader.setState('cropper');
            }

        });

        mediaUploader.open();

    });

    // Helper functions for image cropping
    function edtr_calculate_image_crop(attachment, controller) {

        var control = controller.get('control'),

            realWidth = attachment.get('width'),
            realHeight = attachment.get('height'),

            xInit = parseInt(control.params.width, 10),
            yInit = parseInt(control.params.height, 10),

            ratio = xInit / yInit;


        if ((attachment.attributes.mime === 'image/svg+xml' || attachment.attributes.mime === 'image/svg' ||
            (window.edtr_requiredWidth < 0 || window.edtr_requiredHeight < 0))) { // If one of dimentions is "recommended"
            controller.set('canSkipCrop', true);
        } else {
            controller.set('canSkipCrop', !control.mustBeCropped(xInit, yInit, realWidth, realHeight));
        }


        var xImg = xInit,
            yImg = yInit;

        if (realWidth / realHeight > ratio) {
            yInit = realHeight;
            xInit = yInit * ratio;
        } else {
            xInit = realWidth;
            yInit = xInit / ratio;
        }

        var x1 = (realWidth - xInit) / 2;
        var y1 = (realHeight - yInit) / 2;

        var imgSelectOptions = {
            handles: true,
            keys: true,
            instance: true,
            persistent: true,
            imageWidth: realWidth,
            imageHeight: realHeight,
            minWidth: xImg > xInit ? xInit : xImg,
            minHeight: yImg > yInit ? yInit : yImg,
            x1: x1,
            y1: y1,
            x2: xInit + x1,
            y2: yInit + y1
        };

        return imgSelectOptions;
    }

    function edtr_setImageFromURL(url, attachmentId, width, height, inputSlug) {
        var choice, data = {};

        data.url = url;
        data.thumbnail_url = url;
        data.timestamp = _.now();

        if (attachmentId) {
            data.attachment_id = attachmentId;
        }

        if (width) {
            data.width = width;
        }

        if (height) {
            data.height = height;
        }

        $("#edtr_input_" + inputSlug).val(url);
        $("#img_" + inputSlug).prop("src", url);
    }

    function edtr_setImageFromAttachment(attachment, inputSlug) {
        $("#edtr_input_" + inputSlug).val(attachment.url);
        $("#img_" + inputSlug).prop("src", attachment.url);
    }
})(jQuery);

