<?php

function edtr_add_asyncdefer_attribute($tag, $handle)
{
    // if the unique handle/name of the registered script has 'async' in it
    if (strpos($handle, 'async') !== false) {
        // return the tag with the async attribute
        return str_replace('<script ', '<script async ', $tag);
    } // if the unique handle/name of the registered script has 'defer' in it
    else if (strpos($handle, 'defer') !== false) {
        // return the tag with the defer attribute
        return str_replace('<script ', '<script defer ', $tag);
    } // otherwise skip
    else {
        return $tag;
    }
}

add_filter('script_loader_tag', 'edtr_add_asyncdefer_attribute', 10, 2);


function edtr_get_parameters()
{
    $settings = [];

    if ($partnerID = edtr_validate_return(['option' => 'edtr_general_partner_id', 'type' => 'text']))
        $settings['partnerId'] = $partnerID;

    // Settings
    foreach ([
                 // WP API   EDTR API     TYPE     OBJECT

                 // COLORS
                 ['edtr_primary_color', 'primary', 'color', 'colors'],
                 ['edtr_primary_light_color', 'primaryLight', 'color', 'colors'],
                 ['edtr_primary_active_color', 'primaryActive', 'color', 'colors'],
                 ['edtr_icon_color', 'icon', 'color', 'colors'],

                 // ICONS
                 ['edtr_bot_icon', 'botIconUrl', 'url', 'icons'],
                 ['edtr_header_img', 'headerIconUrl', 'url', 'icons'],
                 ['edtr_widget_icon', 'widgetIconUrl', 'url', 'icons'],

                 // PREVIEW
                 ['edtr_preview_img', 'imgUrl', 'url', 'preview'],
                 ['edtr_preview_title', 'title', 'text', 'preview'],
                 ['edtr_preview_deeplink', 'deeplink', 'text', 'preview']
             ] as $option) {

        if ($current_setting = edtr_validate_return([
            'option' => $option[0],
            'type' => $option[2]
        ])) {
            $settings[$option[3]][$option[1]] = $current_setting;
        }
    }

    return $settings;
}

add_action("wp_enqueue_scripts", "edtr_enqueue_scripts");
function edtr_enqueue_scripts()
{
    $is_enabled = edtr_validate_return([
        'option' => 'edtr_enabled',
        'type' => 'boolean'
    ]);

    if (($is_enabled && edtr_enabled_URL()) || is_admin()) {
        wp_register_script('edtr-bot-script-async', 'https://assets.eddytravels.com/widget.min.js', array(), null);
        wp_add_inline_script('edtr-bot-script-async', 'window.__ET = ' . json_encode(edtr_get_parameters()) . ';', 'before');

        wp_enqueue_script('edtr-bot-script-async');
    }
}

function edtr_enqueue_admin_scripts()
{
    edtr_enqueue_scripts();
}

?>