<?php

function edtr_render_settings()
{
    ?>
    <h1 class="et-title"><?php _e('Eddy Travels integration', 'eddytravels'); ?></h1>


    <div class="et-container">
        <div class="form">
            <form action="options.php" method="POST">
                <?php
                settings_fields('edtr_options');
                do_settings_sections('eddytravels');
                ?>
                <div class="et-submit-container">
                    <input name="preview" class="button button-secondary et-preview" type="button"
                           value="<?php esc_attr_e('Preview changes', 'eddytravels'); ?>"/>
                    <input name="submit" class="button button-primary" type="submit"
                           value="<?php esc_attr_e('Save settings', 'eddytravels'); ?>"/>

                    <?php if (!edtr_validate_return([
                        'option' => 'edtr_enabled',
                        'type' => 'checkbox'
                    ])): ?>
                        <p class="danger"><?php _e('REMINDER: Chatbot integration is <b>DISABLED</b>', 'eddytravels'); ?></p>
                    <?php endif; ?>

                </div>
            </form>
        </div>

        <div class="banner">
            <div class="et-banner">
                <h2><?php _e('Howdy, Partner!', 'eddytravels'); ?></h2>

                <h3><?php _e('About Eddy Travels', 'eddytravels'); ?></h3>
                <p><?php _e('Eddy Travels is an artificial intelligence (AI) travel assistant with the best travel deals just a message away. Over 4 million users worldwide chat with the AI assistant to search flights, hotels, apartments, tours, and car rentals. Now we offer our technology to partners:', 'eddytravels'); ?></p>

                <h3><?php _e('Affiliate Partnerships', 'eddytravels'); ?></h3>
                <p><?php _e('Interested in an affiliate partnership with revenue sharing from travel product purchases?', 'eddytravels'); ?> <a
                            href="https://partner.eddytravels.com/" target="_blank"><?php _e('Sign up here', 'eddytravels'); ?></a> <?php _e('to join the program and receive your unique Partner ID', 'eddytravels'); ?>.

                <h3><?php _e('Enterprise Partnerships', 'eddytravels'); ?></h3>
                <p><?php _e('We are happy to discuss enterprise partnerships and custom projects. Please reach out to us', 'eddytravels'); ?>
                    <a href="https://www.eddytravels.com/contact" target="_blank"><?php _e('here', 'eddytravels'); ?></a>.

                <h3><?php _e('Privacy Policy', 'eddytravels'); ?></h3>
                <p><?php _e('At Eddy Travels we take user security and privacy very seriously. In order to comply with the EU GDPR and other data privacy laws, we have to inform users about the Eddy Travels company and our', 'eddytravels'); ?> <a href="https://www.eddytravels.com/privacy-policy"><?php _e('Privacy Policy', 'eddytravels'); ?></a>. <?php _e('To do that, the chat widget will have this sentence embedded in the chat preview window and in the "Search" menu inside the chat interface: Powered by <b>Eddy Travels</b> | ', 'eddytravels'); ?> <a href="https://www.eddytravels.com/privacy-policy"><?php _e('Privacy Policy', 'eddytravels'); ?></a>.

                <h3><?php _e('Live examples', 'eddytravels'); ?></h3>
                <p><?php _e('Here are some pages for your inspiration that have already Eddy Travels AI Assistant with a Chat Widget installed:', 'eddytravels'); ?>
                <p>
                <ul>
                    <li><a target="_blank" href="https://goa.eddytravels.com">Visit Goa</a></li>
                    <li><a target="_blank"
                           href="https://www.eddytravels.com/deals/2020/11/20/11-of-the-best-dubai-hotels-for-a-perfect-holiday-in-2021">11
                            Best Hotels in Dubai For a Perfect Holiday in 2021</a></li>
                    <li><a target="_blank"
                           href="https://www.eddytravels.com/deals/2020/11/27/top-9-travel-destinations-from-the-uk-after-lockdown">9
                            Stunning Destinations Now Open to UK Travellers</a></li>
                </ul>
                </p>
            </div>
        </div>
    </div>
    <?php
}

function edtr_settings_render_title($args)
{
    return '<h2>' . $args['title'] . '</h2>';
}

function edtr_settings_render_checkbox_input($args)
{
    $input_slug = $args[0];
    $value = edtr_validate_return([
        'option' => $input_slug,
        'type' => 'checkbox'
    ]);
    ?>

    <input id="edtr_input_<?php echo esc_html($input_slug) ?>" name="edtr_options[<?php echo esc_html($input_slug); ?>]"
           type="checkbox"
           value="<?php echo esc_html($value); ?>" <?php echo (boolval(esc_html($value))) ? 'checked' : ''; ?>/>

    <?php if ($args[0] == 'edtr_enabled' && $value): ?><p
        class="success"><?php _e('Chatbot integration is <b>ENABLED</b>', 'eddytravels'); ?></p><?php endif; ?>
    <?php if ($args[0] == 'edtr_enabled' && !$value): ?><p
        class="danger"><?php _e('WARNING: Chatbot integration is <b>DISABLED</b>', 'eddytravels'); ?></p><?php endif; ?>

    <?php if ($args[0] == 'edtr_general_svg'): ?><p>
    <i><?php _e('Turn on this setting to allow vector image upload to your website.', 'eddytravels'); ?></i>
    </p><?php endif; ?>
    <?php
}

function edtr_settings_render_color_input($args)
{
    $input_slug = $args[0];
    $value = edtr_validate_return([
        'option' => $input_slug,
        'type' => 'color'
    ]);

    ?> <input id="edtr_input_<?php echo esc_html($input_slug); ?>"
              name="edtr_options[<?php echo esc_html($input_slug); ?>]" class="et-color" type="text"
              value="<?php echo esc_html($value); ?>"/> <?php
}

function edtr_settings_render_text_input($args)
{
    $input_slug = $args[0];
    $value = edtr_validate_return([
        'option' => $input_slug,
        'type' => 'text'
    ]);

    ?> <input id="edtr_input_<?php echo esc_html($input_slug); ?>"
              name="edtr_options[<?php echo esc_html($input_slug); ?>]" type="text"
              value="<?php echo esc_html($value); ?>"/>

    <?php if ($args[0] == 'edtr_general_partner_id'): ?><p><?php _e('To get your unique Partner ID', 'eddytravels'); ?> – 
    <a href="https://partner.eddytravels.com/"
       target="_blank"><?php _e('SIGN UP HERE', 'eddytravels'); ?></a>.<?php endif; ?>
    <?php if ($args[0] == 'edtr_preview_deeplink'): ?><p><?php _e('To get your unique Deeplink ID,', 'eddytravels'); ?>
    <a href="https://partner.eddytravels.com/"
       target="_blank"><?php _e('contact us', 'eddytravels'); ?></a>.<?php endif; ?>

    <?php
}

function edtr_settings_render_textarea_input($args)
{
    $input_slug = $args[0];
    $value = edtr_validate_return([
        'option' => $input_slug,
        'type' => 'text'
    ]);

    ?> <textarea id="edtr_input_<?php echo esc_html($input_slug); ?>"
                 name="edtr_options[<?php echo esc_html($input_slug); ?>]"><?php echo esc_html($value); ?></textarea>

    <?php if ($args[0] == 'edtr_urls'): ?>
    <p><?php _e('Enter one URL per line. Leave empty to show the chatbot in every page.', 'eddytravels'); ?></p><?php endif; ?>
    <?php
}

function edtr_settings_render_img_input($args)
{
    $input_slug = $args[0];
    $value = edtr_validate_return([
        'option' => $input_slug,
        'type' => 'image'
    ]);

    $img_src = (!empty($value)) ? $value : "data:image/gif;base64,R0lGODlhAQABAAAAACH5BAEKAAEALAAAAAABAAEAAAICTAEAOw==";
    $image = '<img id="img_' . $input_slug . '" src="' . $img_src . '" />';
    echo $image;
    ?>
    <p>
        <?php _e('Recommended size: ', 'eddytravels'); ?> 
        <?php echo (intval($args[2]) > 0) ? esc_html($args[2]) . "px" : "(" . __('not wider than', 'eddytravels') . ' ' . abs($args[2]) . "px)"; ?>
        ×
        <?php echo (intval($args[3]) > 0) ? esc_html($args[3]) . "px" : "(" . __('not higher than', 'eddytravels') . ' ' . abs($args[3]) . "px)"; ?>
    </p>
    <input type="hidden" name="edtr_options[<?php echo esc_html($input_slug); ?>]"
           id="edtr_input_<?php echo esc_html($input_slug); ?>" value="<?php echo esc_html($value); ?>"/>
    <input type="button" class="button-primary et-img-btn" data-input="<?php echo esc_html($input_slug); ?>"
           data-title="<?php echo esc_html($args[1]); ?>"
           data-width="<?php echo esc_html($args[2]); ?>"
           data-height="<?php echo esc_html($args[3]); ?>"
           value="<?php esc_attr_e('Select an image', 'eddytravels'); ?>"
           id="img_button_<?php echo esc_html($input_slug); ?>"/>
    <a href="#" class="et-delete-img"
       data-input="<?php echo esc_html($input_slug); ?>"><?php _e('Reset', 'eddytravels'); ?></a>
    <?php
}

?>