<?php
function edtr_validate_HEX($color)
{
    return preg_match('/^#[a-f0-9]{6}$/i', $color);
}

function edtr_validate_return($args)
{
    //
    $default_values = [
        'foo' => 'bar'
    ];

    $options = get_option('edtr_options');

    if (
        (!isset($options[$args['option']])) || ($options[$args['option']] == ' ') ||     // not an option OR
        ($args['type'] === 'color' && !edtr_validate_HEX($options[$args['option']]))       // or not a color
    ) {
        if (isset($default_values[$args['option']])) {
            if ($args['type'] === 'checkbox')
                return ((int)$default_values[$args['option']] == 1);

            return $default_values[$args['option']];
        } else {
            return false;
        }
    }

    return esc_attr($options[$args['option']]);
}

function edtr_validate_settings($input)
{
    // Validating colors
    $validate_colors = ['edtr_primary_color', 'edtr_primary_light_color', 'edtr_primary_active_color', 'edtr_icon_color'];
    foreach ($input as $key => $value) {
        if (in_array($key, $validate_colors) &&
            !edtr_validate_HEX($value))
            $input[$key] = '';
    }

    // Checkbox'es
    $input['edtr_enabled'] = (int)isset($input['edtr_enabled']);
    $input['edtr_general_svg'] = (int)isset($input['edtr_general_svg']);

    return $input;
}

function edtr_enabled_URL()
{
    $edtr_urls_allowed = edtr_validate_return([
        'option' => 'edtr_urls',
        'type' => 'text'
    ]);

    if (!$edtr_urls_allowed) // no whitelist
        return true;

    $site_url = get_site_url();
    $current_url = (isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? "https" : "http") . "://$_SERVER[HTTP_HOST]$_SERVER[REQUEST_URI]";

    // Strip UTM tags
    $url_parts = parse_url($current_url);
    if (isset($url_parts['query']) && $url_parts['query']) {
        $current_url = str_replace(['?' . $url_parts['query'], $url_parts['query']], '', $current_url);
    }

    $current_relative_url = str_replace($site_url, '', $current_url);

    $edtr_urls_allowed = preg_split('/\n|\r\n?/', $edtr_urls_allowed);

    foreach ($edtr_urls_allowed as $key => $url) {
        if (strpos($url, $site_url) === 0)
            $edtr_urls_allowed[] = str_replace($site_url, '', $url);

        $edtr_urls_allowed[$key] = str_replace('\n', '', $url);
    }

    return in_array($current_relative_url, $edtr_urls_allowed);
}


add_filter('upload_mimes', 'edtr_upload_svg_files');
function edtr_upload_svg_files($allowed)
{
    $svg_enabled = edtr_validate_return([
        'option' => 'edtr_general_svg',
        'type' => 'checkbox'
    ]);

    if ($svg_enabled) {
        $allowed['svg'] = 'image/svg';
        $allowed['svg_xml'] = 'image/svg+xml';
    }

    return $allowed;
}

?>